@@ -2,7 +2,7 @@ context("internal functions")
 
 terra <- rast(ncol = 5, nrow=5, vals = 1)
 
-sf <- readRDS(system.file("external/trainingPolygons.rds", package="RStoolbox"))
+sf <- readRDS(system.file("external/trainingPolygons_lsat.rds", package="RStoolbox"))
 
 test_that("Loaded as sf", {
     expect_is(sf, c("sf", "data.frame"))
